@@ -26,3 +26,23 @@ class MoreThanTwoDataFramesException(AtcException):
 
 class EhJsonToDeltaException(AtcException):
     pass
+
+
+class NoSuchSchemaException(AtcException):
+    pass
+
+
+class FalseSchemaDefinitionException(AtcException):
+    pass
+
+
+class UnregisteredSchemaDefinitionException(AtcException):
+    pass
+
+
+class NoRunId(AtcException):
+    pass
+
+
+class NoDbUtils(AtcException):
+    pass
