@@ -1,7 +1,8 @@
 import time
 import unittest
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 
+from atc_tools.time import dt_utc
 from pyspark.sql import DataFrame
 from pyspark.sql import functions as f
 
@@ -75,7 +76,6 @@ class EventHubsTests(unittest.TestCase):
         tc.register(
             "AtcEh",
             {
-                "name": "AtcEh",
                 "path": f"/mnt/{resourceName()}/silver/{resourceName()}/atceh",
                 "format": "avro",
                 "partitioning": "ymd",
@@ -92,6 +92,17 @@ class EventHubsTests(unittest.TestCase):
         )
         self.assertTrue(df.count(), 2)
 
+        df = eh.read().select("EnqueuedTimestamp")
+        self.assertEqual(
+            df.schema.fields[0].dataType.typeName().upper(),
+            "TIMESTAMP",
+        )
+        row_written: datetime = df.take(1)[0][0]
+        # assert that the eventhub row was written less than 1000 seconds ago
+        self.assertLess(
+            abs((row_written.astimezone(timezone.utc) - dt_utc()).total_seconds()), 1000
+        )
+
     def test_05_eh_json_orchestrator(self):
         # the orchestrator has a complex functionality that can only be fully tested
         # on a substantial holding of capture files. That is not possible here, but
