@@ -2,7 +2,7 @@ from typing import List
 
 from atc_tools.testing import DataframeTestCase
 
-from atc.config_master import TableConfigurator
+from atc import Configurator
 from atc.delta import DbHandle, DeltaHandle
 from atc.etl.loaders.UpsertLoader import UpsertLoader
 from atc.utils import DataframeCreator
@@ -33,8 +33,8 @@ class UpsertLoaderTests(DataframeTestCase):
 
     @classmethod
     def setUpClass(cls) -> None:
-        TableConfigurator().add_resource_path(extras)
-        TableConfigurator().set_debug()
+        Configurator().add_resource_path(extras)
+        Configurator().set_debug()
 
         cls.target_dh_dummy = DeltaHandle.from_tc("UpsertLoaderDummy")
 
